@@ -1,13 +1,13 @@
 import utime
-from machine import Pin, PWM, I2C
 from micropython import const
+import machine
 
 class Pin(object):
     def __init__(self, InA, InB, PWM1):
         self.state = False
-        self.InA = Pin(InA, Pin.OUT)
-        self.InB = Pin(InB, Pin.OUT)
-        self.EN = PWM(Pin(PWM1))
+        self.InA = machine.Pin(InA, machine.Pin.OUT)
+        self.InB = machine.Pin(InB, machine.Pin.OUT)
+        self.EN = machine.PWM(machine.Pin(PWM1))
         self.EN.freq(30000)
 
     def on(self, power):
@@ -35,4 +35,4 @@ class Pin(object):
             self.InB.low()
             self.EN.duty_u16(int(power*655.35))
             utime.sleep_ms(10)
-            self.state = False
\ No newline at end of file
+            self.state = False
